@@ -36,6 +36,7 @@
 #include <glib/gi18n-lib.h>
 #include <glib/gstdio.h>
 
+#include "camel/camel-db.h"
 #include "camel/camel-debug.h"
 #include "camel/camel-exception.h"
 #include "camel/camel-file-utils.h"
@@ -1126,7 +1127,7 @@ imap_forget_folder (CamelImapStore *imap_store, const char *folder_name, CamelEx
 	g_unlink (state_file);
 	g_free (state_file);
 	
-	camel_db_delete_folder (((CamelStore *)imap_store)->cdb, folder_name, ex);
+	camel_db_delete_folder (((CamelStore *)imap_store)->cdb_w, folder_name, ex);
 	camel_imap_message_cache_delete (folder_dir, ex);
 
 	state_file = g_strdup_printf("%s/subfolders", folder_dir);
@@ -1378,7 +1379,9 @@ imap_auth_loop (CamelService *service, CamelException *ex)
 			}
 		}
 		if (!authenticated) {
-			if (camel_exception_get_id(ex) == CAMEL_EXCEPTION_USER_CANCEL)
+			printf("EXCEP %d %d %d\n", camel_exception_get_id(ex), CAMEL_EXCEPTION_USER_CANCEL, CAMEL_EXCEPTION_SERVICE_UNAVAILABLE);
+			if (camel_exception_get_id (ex) == CAMEL_EXCEPTION_USER_CANCEL ||
+			    camel_exception_get_id (ex) == CAMEL_EXCEPTION_SERVICE_UNAVAILABLE)
 				return FALSE;
 
 			errbuf = g_markup_printf_escaped (
@@ -2382,7 +2385,7 @@ parse_list_response_as_folder_info (CamelImapStore *imap_store,
 	if (si == NULL)
 		return NULL;
 
-	newflags = (si->info.flags & CAMEL_STORE_INFO_FOLDER_SUBSCRIBED) | (flags & ~CAMEL_STORE_INFO_FOLDER_SUBSCRIBED);
+	newflags = (si->info.flags & (CAMEL_STORE_INFO_FOLDER_SUBSCRIBED | CAMEL_STORE_INFO_FOLDER_CHECK_FOR_NEW)) | (flags & ~CAMEL_STORE_INFO_FOLDER_SUBSCRIBED);
 	if (si->info.flags != newflags) {
 		si->info.flags = newflags;
 		camel_store_summary_touch((CamelStoreSummary *)imap_store->summary);
@@ -2598,12 +2601,17 @@ fill_fi(CamelStore *store, CamelFolderInfo *fi, guint32 flags)
 	folder = camel_object_bag_peek(store->folders, fi->full_name);
 	if (folder) {
 		CamelImapSummary *ims;
-		ims = (CamelImapSummary *) camel_imap_summary_new (folder, NULL);
+
+		if (folder->summary)
+			ims = (CamelImapSummary *) folder->summary;
+		else
+			ims = (CamelImapSummary *) camel_imap_summary_new (folder, NULL);
 
 		fi->unread = ((CamelFolderSummary *)ims)->unread_count;
 		fi->total = ((CamelFolderSummary *)ims)->saved_count;
 
-		camel_object_unref(ims);
+		if (!folder->summary)
+			camel_object_unref (ims);
 		camel_object_unref(folder);
 	} 
 }
@@ -2992,8 +3000,6 @@ camel_imap_store_connected (CamelImapStore *store, CamelException *ex)
 }
 
 
-/* FIXME: please god, when will the hurting stop? Thus function is so
-   fucking broken it's not even funny. */
 ssize_t
 camel_imap_store_readline (CamelImapStore *store, char **dest, CamelException *ex)
 {
@@ -3066,12 +3072,19 @@ imap_can_refresh_folder (CamelStore *store, CamelFolderInfo *info, CamelExceptio
 	      (camel_url_get_param (((CamelService *)store)->url, "check_all") != NULL) ||
 	      (camel_url_get_param (((CamelService *)store)->url, "check_lsub") != NULL && (info->flags & CAMEL_FOLDER_SUBSCRIBED) != 0);
 
-	if (!res && !camel_exception_is_set (ex)) {
-		CamelFolder *folder;
+	if (!res && !camel_exception_is_set (ex) && CAMEL_IS_IMAP_STORE (store)) {
+		CamelStoreInfo *si;
+		CamelStoreSummary *sm = CAMEL_STORE_SUMMARY (((CamelImapStore *)(store))->summary);
 
-		folder = camel_store_get_folder (store, info->full_name, 0, ex);
-		if (folder && CAMEL_IS_IMAP_FOLDER (folder))
-			res = CAMEL_IMAP_FOLDER (folder)->check_folder;
+		if (!sm)
+			return FALSE;
+
+		si = camel_store_summary_path (sm, info->full_name);
+		if (si) {
+			res = (si->flags & CAMEL_STORE_INFO_FOLDER_CHECK_FOR_NEW) != 0 ? TRUE : FALSE;
+
+			camel_store_summary_info_free (sm, si);
+		}
 	}
 
 	return res;
