@@ -1,6 +1,6 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 /*  Camel
- *  Copyright (C) 1999-2007 Novell, Inc. (www.novell.com)
+ *  Copyright (C) 1999-2008 Novell, Inc. (www.novell.com)
  *
  *  Authors: Jeffrey Stedfast <fejj@novell.com>
  *
@@ -58,7 +58,7 @@
 #include "camel-imap4-summary.h"
 #include "camel-imap4-search.h"
 
-#define d(x) x
+#define d(x)
 
 static void camel_imap4_folder_class_init (CamelIMAP4FolderClass *klass);
 static void camel_imap4_folder_init (CamelIMAP4Folder *folder, CamelIMAP4FolderClass *klass);
@@ -78,7 +78,7 @@ static void imap4_transfer_messages_to (CamelFolder *src, GPtrArray *uids, Camel
 static GPtrArray *imap4_search_by_expression (CamelFolder *folder, const char *expr, CamelException *ex);
 static GPtrArray *imap4_search_by_uids (CamelFolder *folder, const char *expr, GPtrArray *uids, CamelException *ex);
 static void imap4_search_free (CamelFolder *folder, GPtrArray *uids);
-
+static char* imap4_get_filename (CamelFolder *folder, const char *uid, CamelException *ex);
 
 static CamelOfflineFolderClass *parent_class = NULL;
 
@@ -139,6 +139,7 @@ camel_imap4_folder_class_init (CamelIMAP4FolderClass *klass)
 	folder_class->search_by_expression = imap4_search_by_expression;
 	folder_class->search_by_uids = imap4_search_by_uids;
 	folder_class->search_free = imap4_search_free;
+	folder_class->get_filename = imap4_get_filename;
 }
 
 static void
@@ -170,6 +171,14 @@ camel_imap4_folder_finalize (CamelObject *object)
 	g_free (folder->cachedir);
 }
 
+static char*
+imap4_get_filename (CamelFolder *folder, const char *uid, CamelException *ex)
+{
+	CamelIMAP4Folder *imap4_folder = (CamelIMAP4Folder *) folder;
+
+	return camel_data_cache_get_filename (imap4_folder->cache, "cache", uid, ex);
+}
+
 static int
 imap4_getv (CamelObject *object, CamelException *ex, CamelArgGetV *args)
 {
@@ -479,7 +488,7 @@ imap4_sync_flag (CamelFolder *folder, GPtrArray *infos, char onoff, const char *
 		case CAMEL_IMAP4_RESULT_NO:
 			/* FIXME: would be good to save the NO reason into the err message */
 			camel_exception_setv (ex, CAMEL_EXCEPTION_SYSTEM,
-					      _("Cannot sync flags to folder '%s': Unknown"),
+					      _("Cannot sync flags to folder '%s': Unknown error"),
 					      folder->full_name);
 			retval = -1;
 			break;
@@ -625,7 +634,7 @@ imap4_sync (CamelFolder *folder, gboolean expunge, CamelException *ex)
 		case CAMEL_IMAP4_RESULT_NO:
 			/* FIXME: would be good to save the NO reason into the err message */
 			camel_exception_setv (ex, CAMEL_EXCEPTION_SYSTEM,
-					      _("Cannot expunge folder '%s': Unknown"),
+					      _("Cannot expunge folder '%s': Unknown error"),
 					      folder->full_name);
 			break;
 		case CAMEL_IMAP4_RESULT_BAD:
@@ -1178,11 +1187,11 @@ imap4_transfer_messages_to (CamelFolder *src, GPtrArray *uids, CamelFolder *dest
 			/* FIXME: would be good to save the NO reason into the err message */
 			if (move) {
 				camel_exception_setv (ex, CAMEL_EXCEPTION_SYSTEM,
-						      _("Cannot move messages from folder '%s' to folder '%s': Unknown"),
+						      _("Cannot move messages from folder '%s' to folder '%s': Unknown error"),
 						      src->full_name, dest->full_name);
 			} else {
 				camel_exception_setv (ex, CAMEL_EXCEPTION_SYSTEM,
-						      _("Cannot copy messages from folder '%s' to folder '%s': Unknown"),
+						      _("Cannot copy messages from folder '%s' to folder '%s': Unknown error"),
 						      src->full_name, dest->full_name);
 			}
 			
