@@ -49,9 +49,21 @@ struct _ESourceSelector {
 struct _ESourceSelectorClass {
 	GtkTreeViewClass parent_class;
 
-	void (* selection_changed) (ESourceSelector *selector);
-	void (* primary_selection_changed) (ESourceSelector *selector);
-	gboolean (*popup_event)(ESourceSelector *selector, ESource *primary, GdkEventButton *event);
+	void		(*selection_changed)	(ESourceSelector *selector);
+	void		(*primary_selection_changed)
+						(ESourceSelector *selector);
+	gboolean	(*popup_event)		(ESourceSelector *selector,
+						 ESource *primary,
+						 GdkEventButton *event);
+	gboolean	(*data_dropped)		(ESourceSelector *selector,
+						 GtkSelectionData *data,
+						 ESource *destination,
+						 GdkDragAction action,
+						 guint target_info);
+
+	gpointer padding1;
+	gpointer padding2;
+	gpointer padding3;
 };
 
 
@@ -76,11 +88,13 @@ gboolean  e_source_selector_selection_shown  (ESourceSelector *selector);
 
 void e_source_selector_set_select_new (ESourceSelector *selector, gboolean state);
 
+void     e_source_selector_edit_primary_selection  (ESourceSelector *selector);
 ESource *e_source_selector_peek_primary_selection  (ESourceSelector *selector);
 void     e_source_selector_set_primary_selection   (ESourceSelector *selector,
 						    ESource         *source);
 
 ESourceGroup *e_source_selector_get_primary_source_group (ESourceSelector *selector);
+
 G_END_DECLS
 
 #endif /* _E_SOURCE_SELECTOR_H_ */
